#!/usr/bin/env bash
# ------------------------------------------------------------------------------
# This file sets up the environment correctly for building.
# Note that this file thus needs to be sourced.
# ------------------------------------------------------------------------------

# Load helpers for color printing.
source helpers.sh

# Clean all used modules, then load the ones required.
module purge
module load LUMI/23.09 partition/G PrgEnv-cray craype/2.7.23
module load cray-mpich cray-libsci cray-fftw cray-python
module load cray-hdf5-parallel cray-netcdf-hdf5parallel
module load buildtools

# Load the ROCm version as specified by the config.
source versions.sh

if [[ "$ROCMVERSION" == "5.2.3" ]]; then
    info "===> load_modules.sh:  Loading rocm/5.2.3"

    # ROCm 5.2.3 needs to be build with CCE 15.0.1.
    module load cce/15.0.1
    module load rocm/5.2.3
elif [[ "$ROCMVERSION" == "5.4.3" ]]; then
    info "===> load_modules.sh:  Loading rocm/5.4.3"
    
    # ROCm 5.4.3 needs to be build with CCE 16.0.1.
    module load cce/16.0.1

    # Load ROCm/5.4.3 from a custom module.
    module use /pfs/lustrep2/projappl/project_462000125/samantao-public/mymodules
    module load rocm/5.4.3
else
    fatal "===> load_modules.sh:  Provided ROCm version '$ROCMVERSION' not supported"
fi
